'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = middlewareFactory;

var _airbrakeJs = require('airbrake-js');

var _airbrakeJs2 = _interopRequireDefault(_airbrakeJs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function middlewareFactory(credentials) {
  var notify = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  if (!credentials) {
    console.error('Airbrake credentials must be provided for redux-airbrake middleware.');
    return function (store) {
      return function (next) {
        return function (action) {
          next(action);
        };
      };
    };
  }

  var airbrake = new _airbrakeJs2.default(credentials);
  var airbrakeLog = function airbrakeLog(error, params) {
    airbrake.addFilter(function (notice) {
      notice.params = _extends({}, notice.params || {}, params);
      return notice;
    });
    airbrake.notify(_extends({}, notify, { error: error }));
  };

  return function (store) {
    return function (next) {
      return function (action) {
        try {
          return next(action);
        } catch (error) {
          console.error(error);
          var params = {
            reduxAction: action
          };
          airbrakeLog(error, params);
          return error;
        }
      };
    };
  };
}